#
# Conditional build:
%bcond_with	pam		# PAM authentication support
%bcond_without	logdb		# enable mod_logdb (server-side message logging)
#

%define	realname	ejabberd

%define	pgsql_module_rev 1105

Summary:	Fault-tolerant distributed Jabber/XMPP server
Summary(pl.UTF-8):	Odporny na awarie rozproszony serwer Jabbera/XMPP
Name:		%{realname}
Version:	2.1.13
Release:	1
License:	GPL
Group:		Applications/Communications
Source0:	http://www.process-one.net/downloads/ejabberd/%{version}/%{realname}-%{version}.tgz
# Source0-md5:	00f8f28752e6728870cb4c8ad0339984
Source1:	%{realname}.init
Source2:	%{realname}.sysconfig
Source3:	%{realname}.sh
Source4:	%{realname}ctl.sh
Source5:	%{realname}-inetrc
# svn export -r %{pgsql_module_rev} https://svn.process-one.net/ejabberd-modules/pgsql/trunk/src ejabberd-module-pgsql-%{pgsql_module_rev}
Source6:	ejabberd-module-pgsql-%{pgsql_module_rev}.tar.bz2
# Source6-md5:	7a8ba920a508f5180284699610789c14
Patch0:		%{realname}-makefile.patch
Patch1:		%{realname}-config.patch
Patch2:		%{realname}-mod_muc.patch
# http://www.dp.uz.gov.ua/o.palij/mod_logdb/patch-mod_logdb-2.1.12.diff
Patch3:		%{realname}-mod_logdb.patch
Patch4:		%{realname}-vcard-access-get.patch
URL:		http://www.ejabberd.im/
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	erlang >= R10B_5
BuildRequires:	expat-devel >= 1.95
BuildRequires:	openssl-devel
%if %{with pam}
BuildRequires:	pam-devel
%endif
BuildRequires:	rpmbuild(macros) >= 1.268
BuildRequires:	zlib-devel
Requires(post):	/usr/bin/perl
Requires(post):	jabber-common
Requires(post):	sed >= 4.0
Requires(post):	textutils
Requires(post,preun):	/sbin/chkconfig
Requires:	erlang
Requires:	expat >= 1.95
Requires:	rc-scripts
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
ejabberd is a Free and Open Source fault-tolerant distributed Jabber
server. It is written mostly in Erlang.

%description -l pl.UTF-8
ejabberd to darmowy, z otwartymi źródłami, odporny na awarie
rozproszony serwer Jabbera. Jest napisany w większości w Erlangu.

%package logdb
Summary:	Server-side logging module
Group:		Applications/Communications
Requires:	%{name} = %{version}-%{release}

%description logdb
Server-side logging module.

%prep
%setup -q -a 6
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch4 -p1
%if %{with logdb}
%patch3 -p0
%endif

%build
cd src
%{__aclocal}
%{__autoconf}
%configure \
	%{?with_pam --enable-pam} \
	--with-openssl=%{_prefix} \
	--enable-odbc
%{__make} -j1
cd ..
cd ejabberd-module-pgsql-%{pgsql_module_rev}
for f in *.erl ; do
	erlc $f
done
cd ..

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{/var/lib/%{realname},/etc/{sysconfig,rc.d/init.d},%{_sbindir}}

%{__make} -C src install -j1 \
	DESTDIR=$RPM_BUILD_ROOT

sed -e's,@libdir@,%{_libdir},g' -e 's,@EJABBERD_DOC_PATH@,%{_docdir}/%{name}-%{version}/doc,g' %{SOURCE1} > $RPM_BUILD_ROOT/etc/rc.d/init.d/%{realname}
install %{SOURCE2} $RPM_BUILD_ROOT/etc/sysconfig/%{realname}

chmod u+rw $RPM_BUILD_ROOT%{_sbindir}/%{realname}*
sed -e's,@libdir@,%{_libdir},g' %{SOURCE3} > $RPM_BUILD_ROOT%{_sbindir}/%{realname}
sed -e's,@libdir@,%{_libdir},g' %{SOURCE4} > $RPM_BUILD_ROOT%{_sbindir}/%{realname}ctl
install %{SOURCE5} $RPM_BUILD_ROOT%{_sysconfdir}/jabber

chmod 755 $RPM_BUILD_ROOT%{_libdir}/ejabberd/priv/lib/*.so

cd ejabberd-module-pgsql-%{pgsql_module_rev}
for f in *.beam ; do
	install $f $RPM_BUILD_ROOT%{_libdir}/ejabberd/ebin
done
cd ..

%clean
rm -rf $RPM_BUILD_ROOT

%post
if [ -f %{_sysconfdir}/jabber/secret ] ; then
	SECRET=`cat %{_sysconfdir}/jabber/secret`
	if [ -n "$SECRET" ] ; then
		echo "Updating component authentication secret in ejabberd config file..."
		%{__sed} -i -e "s/>secret</>$SECRET</" /etc/jabber/ejabberd.cfg
	fi
fi

if [ ! -f %{_sysconfdir}/jabber/cookie ] ; then
	echo "Generating erl authentication cookie..."
	umask 066
	perl -e 'open R,"/dev/urandom"; read R,$r,16;
		printf "%02x",ord(chop $r) while($r);' > %{_sysconfdir}/jabber/cookie
fi

/sbin/chkconfig --add ejabberd
%service ejabberd restart "ejabberd server"

%preun
if [ "$1" = "0" ]; then
	%service ejabberd stop
	/sbin/chkconfig --del ejabberd
fi

%files
%defattr(644,root,root,755)
%doc doc src/odbc/pg.sql src/odbc/mysql.sql
%attr(755,root,root) %{_sbindir}/*
%attr(640,root,jabber) %config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/jabber/*
%attr(770,root,jabber) /var/log/ejabberd
%if %{with logdb}
%exclude %{_libdir}/ejabberd/ebin/mod_logdb*
%endif
%{_libdir}/ejabberd
%dir %attr(770,root,jabber) /var/lib/ejabberd
%attr(754,root,root) /etc/rc.d/init.d/%{realname}
%attr(640,root,root) %config(noreplace) %verify(not md5 mtime size) /etc/sysconfig/%{realname}

%if %{with logdb}
%files logdb
%defattr(644,root,root,755)
%{_libdir}/ejabberd/ebin/mod_logdb*
%endif
%changelog
* Thu Jul 18 2013 TLD Linux <feedback@tld-linux.org>
- For complete changelog see: http://git.tld-linux.org/?p=packages/ejabberd.git;a=log;h=master

* Sun Jun 30 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 4f310d2
- up to 2.1.13

* Fri Jun 07 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> f2da2f0
- rel 1; ejabberd-vcard-access-get.patch updated from bugreport

* Fri May 17 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 0d78319
- up to 2.1.12; vcard-access-get.patch needs update

* Sun Nov 11 2012 Jan Rękorajski <baggins@pld-linux.org> 864712e
- rebuild with expat 2.1.0
- release 2 (by relup.sh)

* Wed May 16 2012 psz <psz@pld-linux.org> 3f2196e
- up to 2.1.11
- changed homepage

* Wed Jan 04 2012 zbyniu <zbyniu@pld-linux.org> e8bd880
- up to 2.1.10

* Sat Oct 08 2011 ciesiel <ciesiel@pld-linux.org> 539c3a2
- up to 2.1.9

* Sat Jun 11 2011 lisu <lisu@pld-linux.org> f7a00d7
- rel 2

* Fri Jun 10 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> debcdcf
- up to 2.1.8

* Tue Apr 26 2011 Jacek Konieczny <jajcus@pld-linux.org> 059c0ba
- include the pgsql module
- Release: 2

* Wed Feb 02 2011 sparky <sparky@pld-linux.org> 1a2644b
- BR: automake

* Mon Jan 10 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> 6e09432
- up to 2.1.6

* Fri Nov 12 2010 pawelz <pawelz@pld-linux.org> 0400b00
- rel 2

* Tue Aug 17 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> 818026a
- up to 2.1.5

* Tue Jul 06 2010 dzeus <dzeus@pld-linux.org> 379383b
- up to 2.1.4 (bugfixes)

* Wed May 05 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> 5613d9b
- rel 2; catch more so deps

* Sat Apr 17 2010 Arkadiusz Miśkiewicz <arekm@maven.pl> c487c47
- revert fix

* Tue Apr 13 2010 areq <areq@pld-linux.org> d803d5e
- Fix bug in the mod_vcard_ldap.erl changes
  https://support.process-one.net/browse/EJAB-797

* Wed Apr 07 2010 areq <areq@pld-linux.org> 8879bc7
- vcard-access-get.patch - access rule to restrict who is allowed to see vCards of local users

* Wed Apr 07 2010 areq <areq@pld-linux.org> 52421ab
- access rule to restrict who is allowed to see vCards of local users.
  https://support.process-one.net/browse/EJAB-797

